# BINCRAFTERS_REPO_URL = "https://bincrafters.jfrog.io/artifactory/api/conan/public-conan"
BINCRAFTERS_REPO_URL = "https://api.bintray.com/conan/bincrafters/public-conan"
BINCRAFTERS_REPO_NAME = "public-conan"
BINCRAFTERS_LOGIN_USERNAME = "bincrafters-bot"
BINCRAFTERS_USERNAME = "bincrafters"

# TODO: Change REPO_URL once it is clear, why it breaks the tests....
